# Parameters

Some endpoints require input parameters belonging to specific domains.  
On this page, all domains can be found in order to be in line with the standards required by the API.

::: cyhole.jupiter.param
